==> apache-storm-2.0.0-src.zip: apache-storm-2.0.0/storm-client/src/jvm/org/apache/storm/trident/operation/impl/FilterExecutor.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The ASF licenses this file to you under the Apache License, Version
 * 2.0 (the "License"); you may not use this file except in compliance with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package org.apache.storm.trident.operation.impl;

import java.util.Map;
import org.apache.storm.trident.operation.Filter;
import org.apache.storm.trident.operation.Function;
import org.apache.storm.trident.operation.TridentCollector;
import org.apache.storm.trident.operation.TridentOperationContext;
import org.apache.storm.trident.tuple.TridentTuple;

// works by emitting null to the collector. since the planner knows this is an ADD node with
// no new output fields, it just passes the tuple forward
public class FilterExecutor implements Function {
    Filter _filter;

    public FilterExecutor(Filter filter) {
        _filter = filter;
    }

    @Override
    public void execute(TridentTuple tuple, TridentCollector collector) {
        if (_filter.isKeep(tuple)) {
            collector.emit(null);
        }
    }

    @Override
    public void prepare(Map<String, Object> conf, TridentOperationContext context) {
        _filter.prepare(conf, context);
    }

    @Override
    public void cleanup() {
        _filter.cleanup();
    }

}

==> apache-storm-2.8.3-src.zip: apache-storm-2.8.3/storm-client/src/jvm/org/apache/storm/trident/operation/impl/FilterExecutor.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The ASF licenses this file to you under the Apache License, Version
 * 2.0 (the "License"); you may not use this file except in compliance with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package org.apache.storm.trident.operation.impl;

import java.util.Map;
import org.apache.storm.trident.operation.Filter;
import org.apache.storm.trident.operation.Function;
import org.apache.storm.trident.operation.TridentCollector;
import org.apache.storm.trident.operation.TridentOperationContext;
import org.apache.storm.trident.tuple.TridentTuple;

// works by emitting null to the collector. since the planner knows this is an ADD node with
// no new output fields, it just passes the tuple forward
public class FilterExecutor implements Function {
    Filter filter;

    public FilterExecutor(Filter filter) {
        this.filter = filter;
    }

    @Override
    public void execute(TridentTuple tuple, TridentCollector collector) {
        if (filter.isKeep(tuple)) {
            collector.emit(null);
        }
    }

    @Override
    public void prepare(Map<String, Object> conf, TridentOperationContext context) {
        filter.prepare(conf, context);
    }

    @Override
    public void cleanup() {
        filter.cleanup();
    }

}
